package com.ruoyi.web.controller.pc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.req.TRecordResultReq;
import com.ruoyi.system.domain.resp.TRecordResp;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TRecord;
import com.ruoyi.system.service.ITRecordService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 诊断记录信息Controller
 *
 * @author ruoyi
 * @date 2022-08-03
 */
@RestController
@RequestMapping("/system/record")
public class TRecordController extends BaseController
{
    @Autowired
    private ITRecordService tRecordService;

    /**
     * 查询诊断记录信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:record:list')")
    @GetMapping("/list")
    public TableDataInfo list(TRecordResultReq tRecord)
    {
        startPage();
        List<TRecordResp> list = tRecordService.selectTRecordListWithoutResult(tRecord);
        return getDataTable(list);
    }

    /**
     * 导出诊断记录信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:record:export')")
    @Log(title = "诊断记录信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TRecord tRecord)
    {
        List<TRecord> list = tRecordService.selectTRecordList(tRecord);
        ExcelUtil<TRecord> util = new ExcelUtil<TRecord>(TRecord.class);
        util.exportExcel(response, list, "诊断记录信息数据");
    }

    /**
     * 获取诊断记录信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:record:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tRecordService.selectTRecordById(id));
    }

    /**
     * 新增诊断记录信息
     */
    @PreAuthorize("@ss.hasPermi('system:record:add')")
    @Log(title = "诊断记录信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TRecord tRecord)
    {
        return toAjax(tRecordService.insertTRecord(tRecord));
    }

    /**
     * 修改诊断记录信息
     */
    @PreAuthorize("@ss.hasPermi('system:record:edit')")
    @Log(title = "诊断记录信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TRecord tRecord)
    {
        return toAjax(tRecordService.updateTRecord(tRecord));
    }

    /**
     * 删除诊断记录信息
     */
    @PreAuthorize("@ss.hasPermi('system:record:remove')")
    @Log(title = "诊断记录信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tRecordService.deleteTRecordByIds(ids));
    }


}
